'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Text = require('../Text');

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Address = function Address(props) {
  var lines = [];
  var primaryDetails = [];
  var locationDetails = [];
  var countryDetails = [];
  var contactDetails = [];
  var fullCountryDetail = (0, _lodash.isEmpty)(props.state) ? [props.zip, props.city] : [props.zip, props.city + ', ' + props.state];

  if (props.company) {
    primaryDetails.push(_react2.default.createElement(
      'span',
      { className: 'ui-address-element ui-address-company', key: 'company' },
      props.company
    ));
  }

  if (props.first_name || props.last_name) {
    primaryDetails.push(_react2.default.createElement(
      'span',
      { className: 'ui-address-element ui-address-name', key: 'name' },
      [props.first_name, props.last_name].join(' ')
    ));
  }

  if (primaryDetails.length > 0) {
    lines.push(_react2.default.createElement(
      'div',
      { className: 'ui-address-line ui-address-primary-details', key: 'prim' },
      primaryDetails
    ));
  }

  if (props.street || props.street_no) {
    locationDetails.push(_react2.default.createElement(
      'span',
      { className: 'ui-address-element ui-address-street', key: 'street' },
      [props.street, props.street_no].join(' ')
    ));
  }

  if (props.zip || props.city) {
    locationDetails.push(_react2.default.createElement(
      'span',
      { className: 'ui-address-element ui-address-city', key: 'city' },
      fullCountryDetail.join(' ')
    ));
  }

  if (locationDetails.length > 0) {
    lines.push(_react2.default.createElement(
      'div',
      { className: 'ui-address-line ui-address-location-details', key: 'loc' },
      locationDetails
    ));
  }

  if (props.country) {
    countryDetails.push(_react2.default.createElement(
      'span',
      { className: 'ui-address-element ui-address-country', key: 'country' },
      props.country
    ));
  }

  if (countryDetails.length > 0) {
    lines.push(_react2.default.createElement(
      'div',
      { className: 'ui-address-line ui-address-country-details', key: 'coun' },
      countryDetails
    ));
  }

  if (props.email) {
    contactDetails.push(_react2.default.createElement(
      'span',
      { className: 'ui-address-element ui-address-email', key: 'email' },
      _react2.default.createElement(
        'a',
        { href: 'mailto:' + props.email },
        props.email
      )
    ));
  }

  if (props.phone) {
    contactDetails.push(_react2.default.createElement(
      'span',
      { className: 'ui-address-element ui-address-phone', key: 'phone' },
      _react2.default.createElement(
        _Text.Text,
        { muted: true },
        'Fon:'
      ),
      ' ',
      _react2.default.createElement(
        'a',
        { href: 'tel:' + props.phone },
        props.phone
      )
    ));
  }

  if (props.fax) {
    contactDetails.push(_react2.default.createElement(
      'span',
      { className: 'ui-address-element ui-address-fax', key: 'fax' },
      _react2.default.createElement(
        _Text.Text,
        { muted: true },
        'Fax:'
      ),
      ' ',
      props.fax
    ));
  }

  if (contactDetails.length > 0) {
    lines.push(_react2.default.createElement(
      'div',
      { className: 'ui-address-line ui-address-contact-details', key: 'cond' },
      contactDetails
    ));
  }

  return _react2.default.createElement(
    'div',
    {
      className: (0, _classnames2.default)('ui-address', {
        'ui-address-compact': props.compact
      })
    },
    lines
  );
};

Address.propTypes = {
  company: _react2.default.PropTypes.string,
  first_name: _react2.default.PropTypes.string,
  last_name: _react2.default.PropTypes.string,
  street: _react2.default.PropTypes.string,
  street_no: _react2.default.PropTypes.string,
  city: _react2.default.PropTypes.string,
  zip: _react2.default.PropTypes.string,
  country: _react2.default.PropTypes.node,
  phone: _react2.default.PropTypes.string,
  fax: _react2.default.PropTypes.string,
  email: _react2.default.PropTypes.string,
  compact: _react2.default.PropTypes.bool
};

exports.default = Address;