'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Button = require('../Button');

var _AppIcon = require('./AppIcon');

var _AppIcon2 = _interopRequireDefault(_AppIcon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function App(props) {
  var active = props.active,
      activeLabel = props.activeLabel,
      addon = props.addon,
      addButtonLabel = props.addButtonLabel,
      backgroundImageSrc = props.backgroundImageSrc,
      description = props.description,
      developer = props.developer,
      editButtonLabel = props.editButtonLabel,
      height = props.height,
      imageSrc = props.imageSrc,
      onClick = props.onClick,
      price = props.price,
      priceLabel = props.priceLabel,
      title = props.title,
      buttons = props.buttons,
      inactivePending = props.inactivePending,
      inactivePendingLabel = props.inactivePendingLabel;


  var className = (0, _classnames2.default)('ui-app', {
    'ui-app-active': active,
    'ui-app-with-background-image': !!backgroundImageSrc
  });

  var style = {
    height: height ? height + 'px' : null,
    backgroundImage: backgroundImageSrc && 'url("' + backgroundImageSrc + '")'
  };

  function renderPrice() {
    return price && _react2.default.createElement(
      'div',
      { className: 'ui-app-price' },
      price,
      priceLabel && _react2.default.createElement(
        'div',
        { className: 'ui-app-price-label' },
        priceLabel
      )
    );
  }

  function renderDeveloper() {
    return developer && _react2.default.createElement(
      'div',
      { className: 'ui-app-developer' },
      developer
    );
  }

  function renderActiveLabel() {
    return active && _react2.default.createElement(
      'div',
      { className: 'ui-app-active-indicator' },
      activeLabel
    );
  }

  function renderInactivePendingLabel() {
    return inactivePending && _react2.default.createElement(
      'div',
      { className: 'ui-app-inactive-pending-indicator' },
      inactivePendingLabel
    );
  }

  function renderButtons() {
    if (buttons) {
      return buttons;
    }

    return _react2.default.createElement(
      'div',
      null,
      addButtonLabel && !active && _react2.default.createElement(
        'div',
        { className: 'ui-app-add' },
        _react2.default.createElement(
          _Button.Button,
          { onClick: onClick },
          addButtonLabel
        )
      ),
      editButtonLabel && active && _react2.default.createElement(
        'div',
        { className: 'ui-app-add' },
        _react2.default.createElement(
          _Button.Button,
          { onClick: onClick },
          editButtonLabel
        )
      )
    );
  }

  return _react2.default.createElement(
    'div',
    { className: className, onClick: onClick, style: style },
    _react2.default.createElement(
      'div',
      { className: 'ui-app-meta' },
      _react2.default.createElement(
        'div',
        { className: 'ui-app-meta-texts' },
        title && _react2.default.createElement(
          'div',
          { className: 'ui-app-title' },
          title
        ),
        description && _react2.default.createElement(
          'div',
          { className: 'ui-app-description' },
          description
        )
      ),
      imageSrc && _react2.default.createElement(
        'div',
        { className: 'ui-app-meta-icon' },
        _react2.default.createElement(_AppIcon2.default, { src: imageSrc })
      )
    ),
    _react2.default.createElement(
      'div',
      { className: 'ui-app-footer', onClick: function onClick(e) {
          return e.stopPropagation();
        } },
      _react2.default.createElement(
        'div',
        { className: 'ui-app-actions' },
        _react2.default.createElement(
          'div',
          { className: 'ui-app-buttons' },
          renderButtons()
        ),
        _react2.default.createElement(
          'div',
          { className: 'ui-app-info' },
          renderActiveLabel(),
          renderInactivePendingLabel(),
          renderPrice()
        )
      ),
      _react2.default.createElement(
        'div',
        { className: 'ui-app-author' },
        renderDeveloper()
      )
    ),
    addon
  );
}

App.propTypes = {
  active: _react2.default.PropTypes.bool,
  activeLabel: _react2.default.PropTypes.string,
  addButtonLabel: _react2.default.PropTypes.string,
  description: _react2.default.PropTypes.string,
  developer: _react2.default.PropTypes.string,
  editButtonLabel: _react2.default.PropTypes.string,
  height: _react2.default.PropTypes.number,
  imageSrc: _react2.default.PropTypes.string,
  onClick: _react2.default.PropTypes.func,
  price: _react2.default.PropTypes.string,
  priceLabel: _react2.default.PropTypes.string,
  backgroundImageSrc: _react2.default.PropTypes.string,
  title: _react2.default.PropTypes.string,
  buttons: _react2.default.PropTypes.node,
  addon: _react2.default.PropTypes.node
};

App.defaultProps = {
  activeLabel: 'Active'
};

exports.default = App;