'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Button = require('../Button');

var _Icon = require('../Icon');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function AppTheme(props) {
  var browseButtonLabel = props.browseButtonLabel,
      description = props.description,
      onClick = props.onClick,
      title = props.title,
      icon = props.icon,
      palette = props.palette,
      color = props.color,
      height = props.height,
      disabled = props.disabled;


  var style = {
    fill: color ? color : null
  };

  var styleSVG = {
    height: height ? height + 'px' : null
  };

  function renderButtons() {
    return _react2.default.createElement(
      'div',
      null,
      browseButtonLabel && _react2.default.createElement(
        'div',
        { className: 'ui-app-add' },
        _react2.default.createElement(
          _Button.Button,
          { onClick: onClick },
          browseButtonLabel
        )
      )
    );
  }

  function renderIconPalette() {
    return _react2.default.createElement(
      'svg',
      { 'aria-hidden': 'true', focusable: 'false', 'data-prefix': 'fas', 'data-icon': 'palette', className: 'svg-inline--fa fa-palette fa-w-16', role: 'img', xmlns: 'http://www.w3.org/2000/svg', viewBox: '0 0 512 512', style: styleSVG, id: 'svg-palette' },
      _react2.default.createElement('path', { id: 'ui-app-palette', d: 'M204.3 5C104.9 24.4 24.8 104.3 5.2 203.4c-37 187 131.7 326.4 258.8 306.7 41.2-6.4 61.4-54.6 42.5-91.7-23.1-45.4 9.9-98.4 60.9-98.4h79.7c35.8 0 64.8-29.6 64.9-65.3C511.5 97.1 368.1-26.9 204.3 5zM96 320c-17.7 0-32-14.3-32-32s14.3-32 32-32 32 14.3 32 32-14.3 32-32 32zm32-128c-17.7 0-32-14.3-32-32s14.3-32 32-32 32 14.3 32 32-14.3 32-32 32zm128-64c-17.7 0-32-14.3-32-32s14.3-32 32-32 32 14.3 32 32-14.3 32-32 32zm128 64c-17.7 0-32-14.3-32-32s14.3-32 32-32 32 14.3 32 32-14.3 32-32 32z', style: style })
    );
  }

  return _react2.default.createElement(
    'div',
    { className: 'ui-app', onClick: onClick },
    _react2.default.createElement(
      'div',
      { className: 'ui-app-meta ui-app-meta-theme' },
      _react2.default.createElement(
        'div',
        { className: 'ui-app-meta-icon ui-app-meta-icon-flex' },
        !palette && _react2.default.createElement(_Icon.Icon, { name: icon, theme: 'store', disabled: disabled }),
        palette && renderIconPalette()
      ),
      _react2.default.createElement(
        'div',
        { className: 'ui-app-meta-texts ui-app-meta-texts-margin' },
        title && _react2.default.createElement(
          'div',
          { className: 'ui-app-title' },
          title
        ),
        description && _react2.default.createElement(
          'div',
          { className: 'ui-app-description' },
          description
        )
      ),
      _react2.default.createElement(
        'div',
        { className: 'ui-app-actions ui-app-actions-margin' },
        _react2.default.createElement(
          'div',
          { className: 'ui-app-buttons' },
          !disabled && renderButtons()
        )
      )
    )
  );
}

AppTheme.propTypes = {
  browseButtonLabel: _react2.default.PropTypes.string,
  description: _react2.default.PropTypes.string,
  title: _react2.default.PropTypes.string,
  onClick: _react2.default.PropTypes.func,
  icon: _react2.default.PropTypes.string,
  palette: _react2.default.PropTypes.bool,
  height: _react2.default.PropTypes.number,
  color: _react2.default.PropTypes.string,
  disabled: _react2.default.PropTypes.bool
};

AppTheme.defaultProps = {
  palette: false,
  disabled: false
};

exports.default = AppTheme;