'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _reactTooltip = require('react-tooltip');

var _reactTooltip2 = _interopRequireDefault(_reactTooltip);

var _utils = require('../../utils');

var _utils2 = require('../Spacing/utils');

var _Icon = require('../Icon');

var _Spinner = require('../Spinner');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Badge(props) {
  var children = props.children,
      icon = props.icon,
      label = props.label,
      loading = props.loading,
      margin = props.margin,
      padding = props.padding,
      small = props.small,
      theme = props.theme,
      tooltip = props.tooltip;


  var style = (0, _utils2.spacingStyles)({ margin: margin, padding: padding });

  var size = small ? 'small' : 'default';
  var className = (0, _classnames2.default)('ui-badge', 'ui-badge-theme-' + theme, 'ui-badge-size-' + size);

  function renderChildrenWithIcon() {
    if (icon) {
      return _react2.default.createElement(
        'span',
        null,
        _react2.default.createElement(_Icon.Icon, { name: icon, noMargin: true }),
        ' ',
        children
      );
    }

    return _react2.default.createElement(
      'span',
      null,
      _react2.default.createElement(_Spinner.Spinner, null),
      ' ',
      children
    );
  }

  var id = 'button-' + (0, _utils.randomString)(10);

  var badge = _react2.default.createElement(
    'span',
    {
      style: style,
      className: className,
      'data-tip': true,
      'data-for': id
    },
    label && _react2.default.createElement(
      'span',
      { className: 'ui-badge-label' },
      label
    ),
    icon || loading ? renderChildrenWithIcon() : children,
    tooltip && _react2.default.createElement(
      _reactTooltip2.default,
      { effect: 'solid', id: id },
      tooltip
    )
  );

  return badge;
}

Badge.propTypes = {
  children: _react2.default.PropTypes.node,
  icon: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.bool, _react2.default.PropTypes.string]),
  label: _react2.default.PropTypes.string,
  loading: _react2.default.PropTypes.bool,
  margin: _react2.default.PropTypes.string,
  padding: _react2.default.PropTypes.string,
  small: _react2.default.PropTypes.bool,
  theme: _react2.default.PropTypes.oneOf(['success', 'danger', 'default', 'info', 'light']).isRequired,
  tooltip: _react2.default.PropTypes.node
};

Badge.defaultProps = {
  theme: 'default'
};

exports.default = Badge;