'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash');

var _utils = require('../Spacing/utils');

var _Text = require('../Text');

var _Icon = require('../Icon');

var _BoxContent = require('./BoxContent');

var _BoxContent2 = _interopRequireDefault(_BoxContent);

var _BoxHeader = require('./BoxHeader');

var _BoxHeader2 = _interopRequireDefault(_BoxHeader);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Box(props) {
  var borderless = props.borderless,
      centeredLabel = props.centeredLabel,
      children = props.children,
      content = props.content,
      embedded = props.embedded,
      icon = props.icon,
      intro = props.intro,
      label = props.label,
      margin = props.margin,
      noContentPadding = props.noContentPadding,
      onClick = props.onClick,
      padding = props.padding,
      ribbon = props.ribbon,
      theme = props.theme;


  var style = (0, _utils.spacingStyles)({ margin: margin, padding: padding });

  var className = (0, _classnames2.default)('ui-box', 'ui-box-theme-' + theme, {
    'ui-box-borderless': borderless,
    'ui-box-clickable': (0, _lodash.isFunction)(onClick),
    'ui-box-embedded': embedded
  });

  function renderRibbon() {
    if (!ribbon) {
      return null;
    }

    return _react2.default.createElement(
      'div',
      { className: 'ui-box-ribbon-wrapper' },
      _react2.default.createElement(
        'div',
        { className: 'ui-box-ribbon' },
        ribbon
      )
    );
  }

  return _react2.default.createElement(
    'div',
    { style: style, className: className, onClick: onClick },
    renderRibbon(),
    label && _react2.default.createElement(
      _BoxHeader2.default,
      { compact: true, center: centeredLabel },
      icon && _react2.default.createElement(_Icon.Icon, { name: icon }),
      ' ',
      label
    ),
    content && _react2.default.createElement(
      _BoxContent2.default,
      { noPadding: noContentPadding },
      intro && _react2.default.createElement(
        _Text.Text,
        { muted: true, block: true, margin: '2xb' },
        intro
      ),
      content
    ),
    !content && children
  );
}

Box.propTypes = {
  borderless: _react2.default.PropTypes.bool,
  centeredLabel: _react2.default.PropTypes.bool,
  children: _react2.default.PropTypes.node,
  content: _react2.default.PropTypes.node,
  embedded: _react2.default.PropTypes.bool,
  icon: _react2.default.PropTypes.string,
  intro: _react2.default.PropTypes.node,
  label: _react2.default.PropTypes.string,
  margin: _react2.default.PropTypes.string,
  noContentPadding: _react2.default.PropTypes.bool,
  onClick: _react2.default.PropTypes.func,
  padding: _react2.default.PropTypes.string,
  ribbon: _react2.default.PropTypes.node,
  theme: _react2.default.PropTypes.oneOf(['default', 'highlight', 'error', 'info', 'success', 'error-payment']).isRequired
};

Box.defaultProps = {
  theme: 'default',
  embedded: false
};

exports.default = Box;