'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var FlexItem = function FlexItem(_ref) {
  var children = _ref.children,
      widths = _ref.widths,
      width = _ref.width,
      borderRight = _ref.borderRight,
      borderLeft = _ref.borderLeft,
      grow = _ref.grow,
      noShrink = _ref.noShrink;

  var style = {};

  var widthClassNames = (0, _lodash.map)(widths, function (_width, media) {
    return 'ui-flexgrid-item-width-' + media + '-' + _width;
  });

  if (width) {
    style.width = width + 'px';
  }

  var className = (0, _classnames2.default)('ui-flexgrid-item', widthClassNames, {
    'ui-flexgrid-item-border-left': borderLeft,
    'ui-flexgrid-item-border-right': borderRight,
    'ui-flexgrid-item-grow': grow,
    'ui-flexgrid-item-no-shrink': noShrink
  });

  return _react2.default.createElement(
    'div',
    { className: className, style: style },
    children
  );
};

FlexItem.propTypes = {
  children: _react2.default.PropTypes.node,

  /**
   * Specifies the media-widths
   * @type {Object}
   */
  widths: _react2.default.PropTypes.object,

  /**
   * Specifies whether the box should grow
   * @type {Boolean}
   */
  grow: _react2.default.PropTypes.bool,

  /**
   * Specifies whether the box should not shrink
   * @type {Boolean}
   */
  noShrink: _react2.default.PropTypes.bool,

  /**
   * If specified, the item has a fixed pixel-width
   * @type {Integer}
   */
  width: _react2.default.PropTypes.number,

  /**
   * Specifies whether a right border class should be added
   * @type {Boolean}
   */
  borderRight: _react2.default.PropTypes.bool,

  /**
   * Specifies whether a left border class should be added
   * @type {Boolean}
   */
  borderLeft: _react2.default.PropTypes.bool
};

FlexItem.defaultProps = {
  children: null,
  widths: null,
  width: null,
  grow: false,
  noShrink: false,
  borderRight: false,
  borderLeft: false
};

exports.default = FlexItem;