'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash');

var _utils = require('../../utils');

var _Form = require('../Form');

var _utils2 = require('../Spacing/utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Form(props) {
  var children = props.children,
      compact = props.compact,
      data = props.data,
      disabled = props.disabled,
      errors = props.errors,
      inline = props.inline,
      margin = props.margin,
      nativeForm = props.nativeForm,
      onChange = props.onChange,
      pristine = props.pristine,
      requiredText = props.requiredText;


  var i = 0;

  /**
   * Called everytime the value of an form item changes
   *
   * @param name {string} - The field name
   * @param value {any} - The new field value
   */
  var onItemValueChanged = function onItemValueChanged(name, value) {
    // Attribute names can be dot-separated, this is why we use lodash set
    var newData = (0, _lodash.set)(_extends({}, data), name, value);
    onChange(newData);
  };

  /**
   * Filters all errors for a specific field
   *
   * @param allErrors {Array<Object>} - An array of errors
   * @param name {string} - The field name
   */
  var getItemErrors = function getItemErrors(allErrors, name) {
    return allErrors.filter(function (error) {
      return error.field === name;
    });
  };

  var filterNullChilds = function filterNullChilds(child) {
    return !(0, _lodash.isUndefined)(child) && !(0, _lodash.isNull)(child);
  };

  /**
   * Recursively traverses the specified children and updates all those
   * of type FormItem.
   */
  var searchAndUpdateFormItems = function searchAndUpdateFormItems(childs) {
    if ((0, _lodash.size)(childs) === 0) {
      return childs;
    }

    return (0, _lodash.filter)(childs, filterNullChilds).map(function (child) {
      i += 1;

      if ((0, _lodash.isString)(child)) {
        return child;
      }

      if ((0, _lodash.isArray)(child)) {
        return searchAndUpdateFormItems(child);
      }

      var childProps = child.props,
          ChildType = child.type;


      if (ChildType === _Form.FormItem) {
        var _ret = function () {
          var attributeName = child.props.name;
          var newChildProps = (0, _utils.merge)(childProps, {
            onChange: function onChange(value) {
              return onItemValueChanged(attributeName, value);
            },
            errors: getItemErrors(errors, attributeName),
            pristine: pristine,
            disabled: childProps.disabled || disabled,
            requiredText: requiredText,
            inline: inline
          });

          var childCompact = childProps.compact || compact;

          // Attribute names can be dot-separated, this is why we use lodash get
          var value = (0, _lodash.get)(data, attributeName, '');

          return {
            v: _react2.default.createElement(_Form.FormItem, _extends({
              key: i,
              tabIndex: 0,
              value: value,
              compact: childCompact
            }, newChildProps))
          };
        }();

        if ((typeof _ret === 'undefined' ? 'undefined' : _typeof(_ret)) === "object") return _ret.v;
      }

      var newChildren = searchAndUpdateFormItems([].concat((0, _lodash.get)(childProps, 'children', [])));

      return ChildType ? _react2.default.createElement(ChildType, _extends({ key: i }, _extends({}, child.props, { children: newChildren }))) : child;
    });
  };

  // Get the errors which are not specific for certain fields
  var formErrors = errors.length > 0 && _react2.default.createElement(
    'div',
    { className: (0, _classnames2.default)('ui-form-errors') },
    getItemErrors(errors, null).map(function (error, index) {
      return _react2.default.createElement(
        'div',
        { key: index, className: (0, _classnames2.default)('ui-form-error') },
        error.message
      );
    })
  );

  var style = (0, _utils2.spacingStyles)({ margin: margin });
  var className = (0, _classnames2.default)('ui-form', {
    'ui-form-inline': inline
  });

  var WrapperType = nativeForm ? 'form' : 'div';
  var wrapperProps = nativeForm ? {
    onSubmit: function onSubmit(e) {
      return e.preventDefault();
    }
  } : {};

  return _react2.default.createElement(
    WrapperType,
    _extends({ className: className, style: style }, wrapperProps),
    searchAndUpdateFormItems([].concat(children)),
    formErrors
  );
}

Form.propTypes = {
  // Called on FormItem value updates
  onChange: _react2.default.PropTypes.func,

  // Special presentation mode
  compact: _react2.default.PropTypes.bool.isRequired,

  // If specified, all FormItems will be disabled.
  disabled: _react2.default.PropTypes.bool,

  // The required text for all FormItems
  requiredText: _react2.default.PropTypes.string,

  // Object, containing the form data
  data: _react2.default.PropTypes.object,

  // Array containing errors
  errors: _react2.default.PropTypes.array.isRequired,

  // Can be anything. FormItem's will be updated.
  children: _react2.default.PropTypes.node,

  // If specified, overrides the pristine state of the form items
  pristine: _react2.default.PropTypes.bool,

  // Adds top margin
  margin: _react2.default.PropTypes.string,

  // Whether the form should be rendered inline
  inline: _react2.default.PropTypes.bool,

  // If true, a native form element will be used as wrapper
  nativeForm: _react2.default.PropTypes.bool
};

Form.defaultProps = {
  compact: false,
  data: {},
  disabled: false,
  errors: [],
  nativeForm: false,
  pristine: true
};

exports.default = Form;