'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _lodash = require('lodash');

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var FormValidation = function () {
  _createClass(FormValidation, null, [{
    key: 'isCreditCard',
    value: function isCreditCard(number) {
      var bEven = void 0;
      var cDigit = void 0;
      var n = void 0;
      var nCheck = void 0;
      var nDigit = void 0;
      var value = number;

      if (/[^0-9-\s]+/.test(value)) {
        return false;
      }

      // The Luhn Algorithm. It's so pretty.

      nCheck = 0;
      nDigit = 0;
      bEven = false;
      value = value.replace(/\D/g, '');
      n = value.length - 1;

      while (n >= 0) {
        cDigit = value.charAt(n);
        nDigit = (0, _lodash.parseInt)(cDigit, 10);
        if (bEven) {
          var mu = nDigit *= 2;
          if (mu > 9) {
            nDigit -= 9;
          }
        }
        nCheck += nDigit;
        bEven = !bEven;
        n -= 1;
      }

      return nCheck % 10 === 0;
    }
  }, {
    key: 'isValidExpYear',
    value: function isValidExpYear(value) {
      return (0, _lodash.parseInt)(String(value)) >= new Date().getFullYear();
    }
  }, {
    key: 'isValidExpMonth',
    value: function isValidExpMonth(value) {
      var intValue = (0, _lodash.parseInt)(String(value));
      return intValue >= 1 && intValue <= 12;
    }
  }]);

  function FormValidation(messageFunc) {
    _classCallCheck(this, FormValidation);

    this.stack = [];
    this.messageFunc = messageFunc;
  }

  _createClass(FormValidation, [{
    key: 'validate',
    value: function validate(field, validationOrValidations) {
      var messageFunc = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;

      this.stack.push({
        field: field,
        validations: [].concat(validationOrValidations),
        messageFunc: messageFunc || this.messageFunc
      });

      return this;
    }
  }, {
    key: 'run',
    value: function run() {
      var _this = this;

      var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

      var errors = [];

      this.stack.forEach(function (definition) {
        definition.validations.every(function (validation) {
          var errorMessage = _this.getErrorMessage(validation, definition.field, data, definition.messageFunc);
          if (errorMessage) {
            errors.push({
              field: definition.field,
              message: errorMessage
            });
          }
          return (0, _lodash.isNull)(errorMessage);
        });
      });
      return errors;
    }
  }, {
    key: 'getErrorMessage',
    value: function getErrorMessage(validation, field, data) {
      var messageFunc = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;

      var name = (0, _lodash.isObject)(validation) ? (0, _lodash.keys)(validation)[0] : validation;
      var error = null;
      var value = (0, _lodash.get)(data, field);
      var hasField = (0, _lodash.has)(data, field);

      switch (name) {
        case 'required':
          error = !hasField || value === '' || (0, _lodash.isEmpty)((0, _lodash.trim)(value));
          break;

        case 'email':
          error = hasField && value && !String(value).match(/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/);
          break;

        case 'creditCardNumber':
          error = hasField && value && !FormValidation.isCreditCard(value);
          break;

        case 'creditCardExpYear':
          error = hasField && value && !FormValidation.isValidExpYear(value);
          break;

        case 'creditCardExpMonth':
          error = hasField && value && !FormValidation.isValidExpMonth(value);
          break;

        case 'hasKeys':
          error = hasField && value && !((0, _lodash.isPlainObject)(value) || (0, _lodash.keys)(value).length === 0);
          break;

        case 'domainWithSubdomain':
          error = hasField && value && !String(value).match(/^([a-z0-9]([a-z0-9\-]{0,61}[a-z0-9])?\.)+[a-z]{2,10}$/);
          break;

        case 'regex':
          error = hasField && value && !String(value).match(validation[name]);
          break;

        case 'equal':
          error = value !== (0, _lodash.get)(data, validation[name]);
          break;

        case 'minLength':
          error = !hasField || !value || hasField && value.length < validation[name];
          break;

        case 'maxLength':
          error = hasField && value !== null && value.length > validation[name];
          break;

        case 'goodPassword':
          error = !hasField || hasField && !String(value).match(/^(?=.*[0-9])(?=.*[a-z]).{6,}$/);
          break;

        case 'posDecimal':
        case 'weight':
          error = hasField && value && !String(value).match(/^[0-9,.]+$/);
          break;

        case 'posMoney':
          error = hasField && value && !String(value).match(/^[0-9,.]+$/);
          break;

        case 'posInteger':
          error = hasField && value && !String(value).match(/^[0-9]*$/);
          break;

        case 'iban':
          error = hasField && value && !String(value).match(/[a-zA-Z]{2}[0-9]{2}[a-zA-Z0-9]{4}[0-9]{7}([a-zA-Z0-9]?){0,16}/);
          break;

        case 'nonEmptyArray':
          error = !hasField || !(0, _lodash.isArray)(value) || value.length === 0;
          break;

        case 'hourRange':
          error = hasField && value && !String(value).match(/^\d+-\d+$|^\d+$/);
          break;

        case 'isURL':
          error = hasField && value && !String(value).match(/https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{2,256}\.[a-z]{2,4}\b([-a-zA-Z0-9@:%_\+.~#?&//=]*)/);
          break;

        default:
          throw new Error('Unknown validation ' + JSON.stringify(validation));
      }

      if (error) {
        var genericMessage = 'Validation failed: ' + name;
        return messageFunc ? messageFunc(field, name) || genericMessage : genericMessage;
      }

      return null;
    }
  }]);

  return FormValidation;
}();

exports.default = FormValidation;