'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Spinner = require('../Spinner');

var _Progress = require('../Progress');

var _Icon = require('../Icon');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function GalleryItem(props) {
  var addon = props.addon,
      onClick = props.onClick,
      progress = props.progress,
      ribbon = props.ribbon,
      small = props.small,
      size = props.size,
      src = props.src,
      highlighted = props.highlighted,
      medium = props.medium;


  var style = { backgroundImage: 'url("' + src + '")' };
  var linkClassName = (0, _classnames2.default)('ui-gallery-item', {
    'ui-gallery-item-clickable': typeof onClick === 'function'
  });

  var className = (0, _classnames2.default)('ui-gallery-item-wrapper', {
    'ui-gallery-item-wrapper-size-small': small,
    'ui-gallery-item-highlighted': highlighted,
    'ui-gallery-item-wrapper-size-medium': medium
  });

  return _react2.default.createElement(
    'div',
    { className: className },
    ribbon && _react2.default.createElement(
      'div',
      { className: 'ui-gallery-item-ribbon' },
      ribbon
    ),
    !src && _react2.default.createElement(
      'div',
      { className: 'ui-gallery-item-src-missing' },
      _react2.default.createElement(_Icon.Icon, { name: 'ban', large: true })
    ),
    src && _react2.default.createElement(
      'div',
      { className: linkClassName, onClick: onClick },
      _react2.default.createElement(
        'div',
        { className: 'ui-gallery-item-src-loading' },
        _react2.default.createElement(_Spinner.Spinner, null)
      ),
      _react2.default.createElement('div', { className: (0, _classnames2.default)('ui-gallery-item-src'), style: style }),
      progress && _react2.default.createElement(
        'div',
        { className: 'ui-gallery-item-progress' },
        _react2.default.createElement(_Progress.Progress, { progress: progress, small: true, showValue: false })
      )
    ),
    src && addon && _react2.default.createElement(
      'div',
      { className: 'ui-gallery-item-addon' },
      addon
    )
  );
}

GalleryItem.propTypes = {
  // The image src. Can be either a base64 encoded string or an URL
  src: _react2.default.PropTypes.string,

  // Specifies whether the images should appear small
  small: _react2.default.PropTypes.bool,

  // Specifies whether the images should appear medium
  medium: _react2.default.PropTypes.bool,

  // Specifies the click action on the image
  onClick: _react2.default.PropTypes.func,

  // If a progress is given, a progress bar component will be rendered
  // on top of the image (useful for uploader scenarios).
  progress: _react2.default.PropTypes.number,

  // An addon is rendered below the image, could contain actions
  addon: _react2.default.PropTypes.node,

  // A ribbon can be put on top of the item
  ribbon: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.string, _react2.default.PropTypes.bool]),

  // Specifies whether the item is highlighted, e.g. has a special border color
  highlighted: _react2.default.PropTypes.bool
};

GalleryItem.defaultProps = {
  addon: null,
  highlighted: false,
  onClick: null,
  progress: null,
  ribbon: null,
  small: false,
  medium: false,
  src: null
};

exports.default = GalleryItem;