'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _decorators = require('../../decorators');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var FONTAWESOME4 = 'fontawesome4';
var DEVICONS = 'devicons';
var COLORS = {
  sass: '#CD669A',
  css3: '#007DC5',
  html5: '#F05B31',
  javascript: '#F8DC3D'
};

function Icon(props) {
  var className = props.className,
      color = props.color,
      large = props.large,
      light = props.light,
      muted = props.muted,
      name = props.name,
      noMargin = props.noMargin,
      onClick = props.onClick,
      set = props.set,
      size = props.size,
      spin = props.spin,
      theme = props.theme,
      disabled = props.disabled;


  var setClasses = [];
  var sizeClasses = [];
  var style = {};

  if (set === FONTAWESOME4) {
    setClasses.push('fa');
    setClasses.push('fa-fw');
    setClasses.push('fa-' + name);
    if (spin) {
      setClasses.push('fa-spin');
    }
  }

  if (set === DEVICONS) {
    setClasses.push('devicons');
    setClasses.push('devicons-' + name);
  }

  if (color) {
    style.color = COLORS[color] || color;
  }

  if (size && !large) {
    sizeClasses.push('ui-icon-size-' + size);
  }

  if (large) {
    sizeClasses.push('ui-icon-size-large');
  }

  if (disabled) {
    sizeClasses.push('ui-icon-disabled');
  }

  var classNames = (0, _classnames2.default)('ui-icon', 'ui-icon-theme-' + theme, {
    'ui-icon-color-light': light,
    'ui-icon-nomargin': noMargin,
    'ui-text-muted': muted
  }, setClasses, sizeClasses, className);

  return _react2.default.createElement('span', { className: classNames, onClick: onClick, style: style });
}

Icon.propTypes = {
  className: _react2.default.PropTypes.string,
  color: _react2.default.PropTypes.string,
  large: _react2.default.PropTypes.bool,
  light: _react2.default.PropTypes.bool,
  muted: _react2.default.PropTypes.bool,
  name: _react2.default.PropTypes.string.isRequired,
  noMargin: _react2.default.PropTypes.bool,
  onClick: _react2.default.PropTypes.func,
  set: _react2.default.PropTypes.oneOf([FONTAWESOME4, DEVICONS]).isRequired,
  size: _react2.default.PropTypes.oneOf(['default', 'small', 'larger', 'large']),
  spin: _react2.default.PropTypes.bool,
  theme: _react2.default.PropTypes.oneOf(['default', 'success', 'store']),
  disabled: _react2.default.PropTypes.bool
};

Icon.defaultProps = {
  className: null,
  color: null,
  large: false,
  light: false,
  muted: false,
  noMargin: false,
  onClick: null,
  set: FONTAWESOME4,
  size: 'default',
  spin: false,
  theme: 'default',
  disabled: false
};

exports.default = (0, _decorators.tweakable)(Icon);