'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Media = require('../Media');

var _Thumbnail = require('../Thumbnail');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ListItem(props) {
  var active = props.active,
      children = props.children,
      compact = props.compact,
      imageSrc = props.imageSrc,
      imageWidth = props.imageWidth,
      onClick = props.onClick;


  var className = (0, _classnames2.default)('ui-list-item', {
    'ui-list-item-with-onclick': !!onClick,
    'ui-list-item-active': active,
    'ui-list-item-compact': compact
  });

  function renderContent() {
    if (imageSrc) {
      return _react2.default.createElement(
        _Media.Media,
        { compact: compact },
        _react2.default.createElement(
          _Media.MediaIcon,
          null,
          _react2.default.createElement(_Thumbnail.Thumbnail, { src: imageSrc, width: imageWidth })
        ),
        _react2.default.createElement(
          _Media.MediaContent,
          null,
          children
        )
      );
    }

    return children;
  }

  return _react2.default.createElement(
    'div',
    { className: className, onClick: onClick },
    renderContent()
  );
}

ListItem.propTypes = {
  children: _react2.default.PropTypes.node,
  onClick: _react2.default.PropTypes.func,
  active: _react2.default.PropTypes.bool,

  // Renders a compact mode
  compact: _react2.default.PropTypes.bool,

  // If an image is provided it is inserted as media icon
  imageSrc: _react2.default.PropTypes.string,

  // Image with in pixel
  imageWidth: _react2.default.PropTypes.number
};

ListItem.defaultProps = {
  active: false,
  children: null,
  compact: false,
  imageSrc: null,
  imageWidth: 40,
  onClick: null
};

exports.default = ListItem;