'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _mousetrap = require('mousetrap');

var _mousetrap2 = _interopRequireDefault(_mousetrap);

var _lodash = require('lodash');

var _utils = require('../../utils');

var _Form = require('../Form');

var _Dropdown = require('../Dropdown');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Lookup = function (_React$Component) {
  _inherits(Lookup, _React$Component);

  function Lookup(props) {
    _classCallCheck(this, Lookup);

    /**
     * Initial container state
     * @type {Object}
     */
    var _this = _possibleConstructorReturn(this, (Lookup.__proto__ || Object.getPrototypeOf(Lookup)).call(this, props));

    _this.state = {
      data: {},
      results: [],
      loading: false,

      /**
       * Index of the currently focussed result item
       * @type {Integer}
       */
      focussedIndex: null
    };

    /**
     * Bound shortcuts
     * @type {Array}
     */
    _this.shortcuts = [];

    _this.cancelLookup = _this.cancelLookup.bind(_this);
    _this.focusNext = _this.focusNext.bind(_this);
    _this.focusPrevious = _this.focusPrevious.bind(_this);
    _this.onChange = _this.onChange.bind(_this);
    _this.onDropdownOutsideClick = _this.onDropdownOutsideClick.bind(_this);
    _this.selectFocussed = _this.selectFocussed.bind(_this);
    return _this;
  }

  _createClass(Lookup, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.bindShortcuts();
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      this.unbindShortcuts();
    }
  }, {
    key: 'onChange',
    value: function onChange(term) {
      var _this2 = this;

      var onLoad = this.props.onLoad;


      if (term === '') {
        this.setState({ term: '', results: [], dropdownOpen: false });
        return;
      }

      this.setState({ loading: true, term: term });

      var onLoadResult = onLoad(term);

      if (!(0, _utils.isPromise)(onLoadResult)) {
        throw new Error('onLoad must return a Promise');
      }

      onLoadResult.then(function (results) {
        return _this2.setState({
          loading: false,
          results: results
        });
      }).catch(function (error) {
        _this2.setState({ loading: false, results: [] });
        throw error;
      });
    }
  }, {
    key: 'onDropdownOutsideClick',
    value: function onDropdownOutsideClick() {
      this.setState({ dropdownOpen: false });
    }
  }, {
    key: 'onResultItemClick',
    value: function onResultItemClick(resultItem) {
      var onSelect = this.props.onSelect;


      this.setState({ term: '', results: [], focussedIndex: null });

      onSelect(resultItem);
    }
  }, {
    key: 'focusNext',
    value: function focusNext() {
      var _state = this.state,
          results = _state.results,
          focussedIndex = _state.focussedIndex;


      if (results.length > 0) {
        if (focussedIndex === null) {
          this.setState({ focussedIndex: 0 });
        } else if (focussedIndex < results.length - 1) {
          this.setState({ focussedIndex: focussedIndex + 1 });
        }
      }
    }
  }, {
    key: 'focusPrevious',
    value: function focusPrevious() {
      var focussedIndex = this.state.focussedIndex;


      if (focussedIndex > 0) {
        this.setState({ focussedIndex: focussedIndex - 1 });
      }
    }
  }, {
    key: 'selectFocussed',
    value: function selectFocussed() {
      var _state2 = this.state,
          focussedIndex = _state2.focussedIndex,
          results = _state2.results;


      if ((0, _lodash.isInteger)(focussedIndex)) {
        this.onResultItemClick(results[focussedIndex]);
      }
    }
  }, {
    key: 'cancelLookup',
    value: function cancelLookup() {
      this.setState({ results: [], focussedIndex: null });
    }
  }, {
    key: 'bindShortcuts',
    value: function bindShortcuts() {
      _mousetrap2.default.bind('down', this.focusNext);
      _mousetrap2.default.bind('up', this.focusPrevious);
      _mousetrap2.default.bind('enter', this.selectFocussed);
      _mousetrap2.default.bind('esc', this.cancelLookup);
    }
  }, {
    key: 'unbindShortcuts',
    value: function unbindShortcuts() {
      _mousetrap2.default.unbind('down');
      _mousetrap2.default.bind('up');
      _mousetrap2.default.unbind('enter');
      _mousetrap2.default.unbind('esc');
    }
  }, {
    key: 'render',
    value: function render() {
      var _this3 = this;

      var _props = this.props,
          itemBuilder = _props.itemBuilder,
          inputAddon = _props.inputAddon,
          placeholder = _props.placeholder,
          prefix = _props.prefix;
      var _state3 = this.state,
          results = _state3.results,
          term = _state3.term,
          loading = _state3.loading,
          focussedIndex = _state3.focussedIndex;


      var dropdown = _react2.default.createElement(
        _Dropdown.Dropdown,
        {
          open: results.length > 0,
          onOutsideClick: this.onDropdownOutsideClick,
          focussedIndex: focussedIndex
        },
        results.map(function (resultItem, index) {
          return _react2.default.createElement(_Dropdown.DropdownItem, {
            key: index,
            body: itemBuilder(resultItem),
            onClick: function onClick() {
              return _this3.onResultItemClick(resultItem);
            }
          });
        })
      );

      return _react2.default.createElement(_Form.FormItem, {
        type: 'text',
        name: 'term',
        value: term,
        dropdown: dropdown,
        onChange: this.onChange,
        innerAddon: inputAddon,
        placeholder: placeholder,
        spinner: loading,
        prefix: prefix
      });
    }
  }]);

  return Lookup;
}(_react2.default.Component);

Lookup.propTypes = {
  /**
   * Invoked when the user types something
   * @type {Function}
   */
  onLoad: _react2.default.PropTypes.func.isRequired,

  /**
   * Called when the user selects an item
   * @type {Function}
   */
  onSelect: _react2.default.PropTypes.func.isRequired,

  /**
   * Invoked to render the dropdown items
   * @type {Function}
   */
  itemBuilder: _react2.default.PropTypes.func.isRequired,

  /**
   * Additional JSX rendered as addon into the input
   * @type {Object}
   */
  inputAddon: _react2.default.PropTypes.node,

  /**
   * Input placeholder
   * @type {String}
   */
  placeholder: _react2.default.PropTypes.string,

  /**
   * Input prefix
   * @type {String}
   */
  prefix: _react2.default.PropTypes.string
};

exports.default = Lookup;