'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash');

var _utils = require('../../utils');

var _Icon = require('../Icon');

var _Copyable = require('../Copyable');

var _Form = require('../Form');

var _Button = require('../Button');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var TableCell = function (_Component) {
  _inherits(TableCell, _Component);

  function TableCell(props) {
    _classCallCheck(this, TableCell);

    /**
     * Reference to the edit control input.
     */
    var _this = _possibleConstructorReturn(this, (TableCell.__proto__ || Object.getPrototypeOf(TableCell)).call(this, props));

    _this.onCellClick = function () {
      var onEdit = _this.props.onEdit;


      if (onEdit) {
        _this.setState({
          editing: true,
          editingValue: _this.getEditingValue()
        }, _this.focusEditControl);
      }

      return null;
    };

    _this.onCancelClick = function () {
      _this.setState({
        editing: false,
        editingValue: null
      });
    };

    _this.onSaveClick = function () {
      var _this$props = _this.props,
          datum = _this$props.datum,
          editable = _this$props.editable,
          onEdit = _this$props.onEdit;


      if (editable) {
        var prevValue = _this.getEditingValue();
        var editingValue = _this.state.editingValue;

        // Skip everything if the value did not change

        if (prevValue === editingValue) {
          _this.setState({
            editing: false,
            editingValue: null
          });
        } else {
          var newDatum = _extends({}, datum, _defineProperty({}, editable, editingValue));

          var result = onEdit(newDatum);

          if ((0, _utils.isPromise)(result)) {
            _this.setState({ saving: true });

            result.then(function (nextDatum) {
              return _this.onSaveFinished(nextDatum);
            });
          } else {
            _this.onSaveFinished(result);
          }
        }
      }
    };

    _this.onSaveFinished = function (newDatum) {
      var _this$props2 = _this.props,
          datum = _this$props2.datum,
          onUpdateDatum = _this$props2.onUpdateDatum;


      _this.setState({
        editing: false,
        editingValue: null,
        saving: false
      });

      if (onUpdateDatum) {
        onUpdateDatum(datum, newDatum);
      }
    };

    _this.onEditingValueChange = function (value) {
      _this.setState({
        editingValue: value,
        editingErrors: _this.getEditingErrors(value)
      });
    };

    _this.setEditControlRef = function (ref) {
      _this.editControlRef = ref;
    };

    _this.focusEditControl = function () {
      if (_this.editControlRef) {
        _this.editControlRef.focus();
      }
    };

    _this.editControlRef = null;

    _this.state = {
      sorted: false,

      // Specifies whether this cell is in edit mode
      editing: false,

      // This tracks the editing updates until commit
      editingValue: null,

      // Validation errors happening during editing
      editingErrors: _this.getEditingErrors(_this.getEditingValue()),

      // Specifies whether a commit is in progress
      saving: false
    };
    return _this;
  }

  /**
   * Required to focus the field
   */


  _createClass(TableCell, [{
    key: 'getEditingValue',


    /**
     * Determine the value to be edited from the datum and `editable` prop.
     * If it is not available, use an empty string.
     *
     * @return {string}
     */
    value: function getEditingValue() {
      var _props = this.props,
          datum = _props.datum,
          editable = _props.editable;


      if (!datum) {
        return '';
      }

      return datum[editable] || '';
    }

    /**
     * Get errors for this field
     *
     * @param {string} value
     * @return {array}
     */

  }, {
    key: 'getEditingErrors',
    value: function getEditingErrors(value) {
      var _props2 = this.props,
          datum = _props2.datum,
          editable = _props2.editable,
          onValidate = _props2.onValidate;


      if (editable && onValidate) {
        var payload = _extends({}, datum, _defineProperty({}, editable, value));

        var errors = onValidate(payload);

        return errors;
      }

      return [];
    }
  }, {
    key: 'renderClassName',
    value: function renderClassName() {
      var _props3 = this.props,
          bold = _props3.bold,
          center = _props3.center,
          expander = _props3.expander,
          onEdit = _props3.onEdit,
          orderHandle = _props3.orderHandle,
          right = _props3.right,
          customClass = _props3.customClass,
          breakCell = _props3.breakCell;
      var editing = this.state.editing;


      if (breakCell) {
        return (0, _classnames2.default)('ui-table-cell-break', {}, customClass);
      } else {
        return (0, _classnames2.default)('ui-table-cell', {
          'ui-table-cell-bold': bold,
          'ui-table-cell-center': center,
          'ui-table-cell-editable': onEdit,
          'ui-table-cell-editing': editing,
          'ui-table-cell-expander': expander,
          'ui-table-cell-order-handle': orderHandle,
          'ui-table-cell-right': right
        }, customClass);
      }
    }
  }, {
    key: 'renderStyles',
    value: function renderStyles() {
      var width = this.props.width;


      return {
        flex: width ? '0 0 ' + width + 'px' : null
      };
    }
  }, {
    key: 'renderEditingCell',
    value: function renderEditingCell() {
      var _this2 = this;

      var cancelLabel = this.props.cancelLabel;
      var _state = this.state,
          editingValue = _state.editingValue,
          editingErrors = _state.editingErrors,
          saving = _state.saving;


      var suffix = _react2.default.createElement(
        _Button.ButtonGroup,
        null,
        _react2.default.createElement(_Button.Button, {
          icon: 'save',
          loading: saving,
          onClick: this.onSaveClick,
          type: 'submit',
          disabled: editingErrors.length > 0
        })
      );

      var addon = _react2.default.createElement(
        _Button.Button,
        { margin: '0.5xt', disabled: saving, onClick: this.onCancelClick, theme: 'link' },
        cancelLabel
      );

      return _react2.default.createElement(
        'div',
        { className: this.renderClassName(), style: this.renderStyles() },
        _react2.default.createElement(
          _Form.Form,
          {
            nativeForm: true,
            onChange: function onChange(_ref) {
              var newValue = _ref.newValue;
              return _this2.onEditingValueChange(newValue);
            },
            disabled: saving
          },
          _react2.default.createElement(_Form.FormItem, {
            suffix: suffix,
            type: 'text',
            value: editingValue,
            name: 'newValue',
            controlRef: this.setEditControlRef,
            addon: addon
          })
        )
      );
    }
  }, {
    key: 'render',
    value: function render() {
      var _this3 = this;

      var title = this.props.title;
      var editing = this.state.editing;


      var isCopyable = this.props.copyable;
      var value = this.props.value;
      var setSorted = function setSorted(direction) {
        _this3.setState({ sorted: direction });
      };

      // If copyable and/or bold is requested, wrap the content
      var content = isCopyable ? _react2.default.createElement(
        _Copyable.Copyable,
        null,
        value
      ) : value;
      var noContent = (0, _lodash.isUndefined)(content);

      // This is a wrapper around the sepcified sort callback which
      // injects the requested direction as a parameter to the original
      // callback
      var onSort = this.props.onSort ? function (direction) {
        return function () {
          var result = _this3.props.onSort(direction);

          // Check if the result is a promise. If so, wait for it to be fulfilled
          // before updating the internal state.
          if ((0, _utils.isPromise)(result)) {
            result.then(function () {
              return setSorted(direction);
            });
          } else {
            setSorted(direction);
          }
        };
      } : null;

      // Build the icon if specified
      var icon = this.props.icon ? _react2.default.createElement(_Icon.Icon, { name: this.props.icon, noMargin: noContent }) : null;

      // Build the cells styles


      // If onSort is defined, a suffix should be added
      var suffix = typeof onSort === 'function' ? _react2.default.createElement(
        'div',
        {
          className: (0, _classnames2.default)('ui-table-cell-suffix', 'ui-table-sort', {
            'ui-table-sort-asc': this.state.sorted === 1,
            'ui-table-sort-desc': this.state.sorted === -1
          })
        },
        _react2.default.createElement(_Icon.Icon, { name: 'caret-up', onClick: onSort(1) }),
        _react2.default.createElement(_Icon.Icon, { name: 'caret-down', onClick: onSort(-1) })
      ) : null;

      if (editing) {
        return this.renderEditingCell();
      }

      return _react2.default.createElement(
        'div',
        {
          className: this.renderClassName(),
          style: this.renderStyles(),
          onClick: this.onCellClick,
          tabIndex: 0
        },
        title && _react2.default.createElement(
          'div',
          { className: 'ui-table-cell-title' },
          title
        ),
        _react2.default.createElement(
          'div',
          { className: 'ui-table-cell-content' },
          _react2.default.createElement(
            'span',
            { className: 'ui-table-cell-text' },
            icon,
            content
          ),
          suffix
        )
      );
    }
  }]);

  return TableCell;
}(_react.Component);

TableCell.propTypes = {
  bold: _react2.default.PropTypes.bool,
  center: _react2.default.PropTypes.bool,
  copyable: _react2.default.PropTypes.bool,
  icon: _react2.default.PropTypes.string,
  onSort: _react2.default.PropTypes.func,
  orderHandle: _react2.default.PropTypes.bool,
  right: _react2.default.PropTypes.bool,
  title: _react2.default.PropTypes.node,
  value: _react2.default.PropTypes.node,
  width: _react2.default.PropTypes.number,
  expander: _react2.default.PropTypes.bool,
  onEdit: _react2.default.PropTypes.func,
  datum: _react2.default.PropTypes.object,
  editable: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.string, _react2.default.PropTypes.bool]),
  onUpdateDatum: _react2.default.PropTypes.func,
  onValidate: _react2.default.PropTypes.func,
  cancelLabel: _react2.default.PropTypes.string,
  breakCell: _react2.default.PropTypes.bool
};
TableCell.defaultProps = {
  header: null,
  onEdit: null,
  editable: false,
  expander: false,
  datum: null,
  onUpdateDatum: null,
  onValidate: null,
  cancelLabel: null,
  breakCell: false
};
exports.default = TableCell;