'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash');

var _TableCell = require('./TableCell');

var _TableCell2 = _interopRequireDefault(_TableCell);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var determineCellValue = function determineCellValue(column, datum, isHeaderRow, index) {
  var builder = column.props.builder;
  var attribute = column.props.attribute;
  var formatter = column.props.formatter;

  var value = null;

  // If this is the header row, return the title
  if (isHeaderRow) {
    value = column.props.title;
  } else {
    // If the column has a builder func, use that
    if (builder) {
      value = builder(datum, index);
    } else if (attribute) {
      // If teh attribute is a dot-separated string,
      // find the value within the datum
      if (attribute.match(/\./)) {
        value = (0, _lodash.get)(datum, attribute);
      } else {
        value = datum[attribute];
      }
    } else {
      value = null;
    }

    // If a formatter is present, apply it in the value
    if (formatter) {
      value = formatter.format(value);
    }
  }

  return value;
};

var TableRow = function TableRow(props) {
  var addon = props.addon,
      cancelLabel = props.cancelLabel,
      children = props.children,
      columns = props.columns,
      datum = props.datum,
      expansion = props.expansion,
      isHeaderRow = props.header,
      index = props.index,
      onRowClick = props.onRowClick,
      onUpdateDatum = props.onUpdateDatum,
      onValidate = props.onValidate;

  // Is this row clickable

  var isClickable = typeof onRowClick === 'function';
  var onClick = onRowClick ? function (event) {
    return props.onRowClick(event, datum);
  } : null;

  // A row can have an addon which is placed below the default content
  var rowAddon = addon ? _react2.default.createElement(
    'div',
    { className: (0, _classnames2.default)('ui-table-row-addon') },
    props.addon
  ) : null;

  // Build the cells
  var cells = columns ? columns.map(function (column, columnIndex) {
    var _column$props = column.props,
        bold = _column$props.bold,
        center = _column$props.center,
        copyable = _column$props.copyable,
        editable = _column$props.editable,
        expander = _column$props.expander,
        icon = _column$props.icon,
        onEdit = _column$props.onEdit,
        onSort = _column$props.onSort,
        orderHandle = _column$props.orderHandle,
        right = _column$props.right,
        title = _column$props.title,
        width = _column$props.width,
        customClass = _column$props.customClass,
        breakCell = _column$props.breakCell;


    return _react2.default.createElement(_TableCell2.default, {
      bold: bold && !isHeaderRow,
      center: center,
      copyable: copyable && !isHeaderRow,
      datum: datum,
      expander: expander,
      editable: !isHeaderRow && editable,
      onEdit: isHeaderRow ? null : onEdit,
      icon: isHeaderRow ? icon : null,
      key: columnIndex,
      onSort: isHeaderRow ? onSort : null,
      orderHandle: orderHandle,
      right: right,
      title: title,
      value: determineCellValue(column, datum, isHeaderRow, index),
      width: width,
      onUpdateDatum: onUpdateDatum,
      onValidate: onValidate,
      cancelLabel: cancelLabel,
      customClass: customClass || '',
      breakCell: breakCell
    });
  }) : children;

  return _react2.default.createElement(
    'div',
    { className: (0, _classnames2.default)('ui-table-row-wrapper') },
    _react2.default.createElement(
      'div',
      {
        onClick: onClick,
        className: (0, _classnames2.default)('ui-table-row', {
          'ui-table-row-clickable': isClickable,
          'ui-table-row-highlighted': props.highlighted
        })
      },
      cells
    ),
    rowAddon,
    expansion && _react2.default.createElement(
      'div',
      { className: 'ui-table-row-expansion' },
      expansion
    )
  );
};

TableRow.propTypes = {
  datum: _react2.default.PropTypes.object,
  columns: _react2.default.PropTypes.array,
  header: _react2.default.PropTypes.bool,
  onRowClick: _react2.default.PropTypes.func,
  highlighted: _react2.default.PropTypes.bool,
  children: _react2.default.PropTypes.node,
  addon: _react2.default.PropTypes.node,
  index: _react2.default.PropTypes.any,
  expansion: _react2.default.PropTypes.node,
  onUpdateDatum: _react2.default.PropTypes.func,
  onValidate: _react2.default.PropTypes.func,
  cancelLabel: _react2.default.PropTypes.string
};

TableRow.defaultProps = {
  expansion: null,
  onUpdateDatum: null,
  onValidate: null,
  cancelLabel: null
};

exports.default = TableRow;