'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _lodash = require('lodash');

var _TabV = require('./TabV2');

var _TabV2 = _interopRequireDefault(_TabV);

var _Icon = require('../Icon');

var _Badge = require('../Badge');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Tabs(_ref) {
  var embedded = _ref.embedded,
      children = _ref.children,
      onChange = _ref.onChange,
      active = _ref.active;

  var filterTabs = function filterTabs(item) {
    return (0, _lodash.get)(item, 'type') === _TabV2.default;
  };

  function renderHeader(tab, index) {
    var tabName = (0, _lodash.get)(tab, 'props.id');
    var onClick = function onClick() {
      if (tabName !== active) {
        onChange(tabName);
      }
    };
    var className = (0, _classnames2.default)('ui-tab-header', {
      'ui-tab-header-active': tabName === active
    });
    var icon = (0, _lodash.get)(tab, 'props.icon');
    var title = (0, _lodash.get)(tab, 'props.title');
    var badge = (0, _lodash.get)(tab, 'props.badge');
    var image = (0, _lodash.get)(tab, 'props.image');

    return _react2.default.createElement(
      'a',
      { key: index, tabIndex: index, onClick: onClick, className: className },
      icon && _react2.default.createElement(_Icon.Icon, { name: icon }),
      title,
      badge && _react2.default.createElement(
        _Badge.Badge,
        { margin: '1xl', theme: 'info' },
        badge
      ),
      image && _react2.default.createElement('img', { src: image, role: 'presentation' })
    );
  }

  function renderHeaders() {
    return _react2.default.createElement(
      'div',
      { className: 'ui-tabs-headers' },
      [].concat(children).filter(filterTabs).map(renderHeader)
    );
  }

  function renderTab(tab, index) {
    var tabName = (0, _lodash.get)(tab, 'props.id');

    if (tabName !== active) {
      return null;
    }

    var builder = (0, _lodash.get)(tab, 'props.builder');

    var buildTabContent = function buildTabContent() {
      if (builder) {
        return builder(tabName);
      }

      return tab.props.children;
    };

    var newProps = _extends({}, tab.props, {
      key: index,
      children: buildTabContent()
    });

    return _react2.default.createElement(_TabV2.default, newProps);
  }

  function renderTabs() {
    return _react2.default.createElement(
      'div',
      { className: 'ui-tabs-contents' },
      [].concat(children).filter(filterTabs).map(renderTab)
    );
  }

  var className = (0, _classnames2.default)('ui-tabs', {
    'ui-tabs-embedded': embedded
  });
  return _react2.default.createElement(
    'div',
    { className: className },
    renderHeaders(),
    renderTabs()
  );
}

Tabs.propTypes = {
  children: _react2.default.PropTypes.node,
  embedded: _react2.default.PropTypes.bool,

  // Name of the active tab (optional)
  active: _react2.default.PropTypes.string,

  // Called when the tab changes
  onChange: _react2.default.PropTypes.func
};

Tabs.defaultProps = {};

exports.default = Tabs;