'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function Wizard(props) {
  var active = props.active,
      children = props.children,
      disabled = props.disabled,
      onChange = props.onChange,
      prefix = props.prefix;

  /**
   * Builds indicators for each wizardStep
   *
   * @return {array}
   */

  var renderIndicators = function renderIndicators() {
    return [].concat(children).map(function (_ref, index) {
      var wizardStepProps = _ref.props;
      var done = wizardStepProps.done,
          id = wizardStepProps.id,
          label = wizardStepProps.label;


      var className = (0, _classnames2.default)('ui-wizard-indicator', {
        'ui-wizard-indicator-active': id === active,
        'ui-wizard-indicator-done': done
      });

      var onClick = function onClick() {
        // The entire wizard might be disabled

        if (disabled) {
          return;
        }
        // Only trigger change when the new id is different from the current one
        if (id !== active) {
          onChange(id);
        }
      };

      return _react2.default.createElement(
        'div',
        { className: className, key: index, onClick: onClick, tabIndex: 0 },
        _react2.default.createElement('span', { className: 'ui-wizard-indicator-bubble' }),
        label
      );
    });
  };

  /**
   * Filter the active child
   *
   * @return {array}
   */
  var activeChildren = [].concat(children).filter(function (child) {
    return child.props.id === active;
  });

  /**
   * Renders the wizard step contents
   *
   * @return {array}
   */
  var renderChildren = function renderChildren() {
    return activeChildren.map(function (_ref2, index) {
      var wizardStepProps = _ref2.props;

      var className = (0, _classnames2.default)('ui-wizard-content');

      return _react2.default.createElement(
        'div',
        { className: className, key: index },
        wizardStepProps.children
      );
    });
  };

  return _react2.default.createElement(
    'div',
    { className: 'ui-wizard' },
    _react2.default.createElement(
      'div',
      { className: 'ui-wizard-indicators' },
      renderIndicators()
    ),
    prefix && _react2.default.createElement(
      'div',
      { className: 'ui-wizard-prefix' },
      prefix
    ),
    _react2.default.createElement(
      'div',
      { className: 'ui-wizard-contents' },
      renderChildren()
    )
  );
}

Wizard.propTypes = {
  // Triggered on step click (only if the step is not disabled)
  onChange: _react2.default.PropTypes.func,

  // Identifier of the active step
  active: _react2.default.PropTypes.string,

  // Wizard steps
  children: _react2.default.PropTypes.node,

  // Rendered directly after the steps
  prefix: _react2.default.PropTypes.node,

  // Whether the steps are all disabled
  disabled: _react2.default.PropTypes.bool
};

Wizard.defaultProps = {
  active: null,
  children: null,
  disabled: false,
  onChange: null,
  prefix: null
};

exports.default = Wizard;